@@ -1,33 +1,42 @@
-#' Use Catalogue of Life to get downstream taxa to a given taxonomic level.
+#' Use Catalogue of Life to get downstream taxa to a given taxonomic level
 #'
-#' @param name The string to search for. Only exact matches found the name given
-#'     will be returned, unless one or wildcards are included in the search
-#'   	string. An * (asterisk) character denotes a wildcard; a % (percentage)
-#'    character may also be used. The name must be at least 3 characters long,
-#'    not counting wildcard characters.
-#' @param id The record ID of the specific record to return (only for scientific
-#'   	names of species or infraspecific taxa)
-#' @param downto The taxonomic level you want to go down to. See examples below.
-#' 		The taxonomic level IS case sensitive, and you do have to spell it
-#' 		correctly. See \code{data(rank_ref)} for spelling.
-#' @param format The returned format (default = NULL). If NULL xml is used.
-#'    Currently only xml is supported.
-#' @param start  The first record to return (default = NULL). If NULL, the
-#'    results are returned from the first record (start=0). This is useful if
-#'    the total number of results is larger than the maximum number of results
-#'    returned by a single Web service query (currently the maximum number of
-#'    results returned by a single query is 500 for terse queries and 50 for
-#'    full queries).
-#' @param checklist The year of the checklist to query, if you want a specific
-#' 		year's checklist instead of the lastest as default (numeric).
-#' @param verbose Print or suppress messages.
-#' @param intermediate (logical) If TRUE, return a list of length two with target
-#'    taxon rank names, with additional list of data.frame's of intermediate
-#'    taxonomic groups. Default: FALSE
-#' @param ... Curl options passed on to \code{\link[httr]{GET}}
-#' @details Provide only names instead of id's
-#' @return A list of data.frame's.
 #' @export
+#' @param name The string to search for. Only exact matches found the name given
+#' will be returned, unless one or wildcards are included in the search
+#' string. An * (asterisk) character denotes a wildcard; a % (percentage)
+#' character may also be used. The name must be at least 3 characters long,
+#' not counting wildcard characters.
+#' @param id The record ID of the specific record to return (only for scientific
+#' names of species or infraspecific taxa)
+#' @param downto The taxonomic level you want to go down to. See examples below.
+#' The taxonomic level IS case sensitive, and you do have to spell it
+#' correctly. See \code{data(rank_ref)} for spelling.
+#' @param format The returned format (default = NULL). If NULL xml is used.
+#' Currently only xml is supported.
+#' @param start  The first record to return (default = NULL). If NULL, the
+#' results are returned from the first record (start=0). This is useful if
+#' the total number of results is larger than the maximum number of results
+#' returned by a single Web service query (currently the maximum number of
+#' results returned by a single query is 500 for terse queries and 50 for
+#' full queries).
+#' @param checklist The year of the checklist to query, if you want a specific
+#' year's checklist instead of the lastest as default (numeric).
+#' @param verbose Print or suppress messages.
+#' @param intermediate (logical) If \code{TRUE}, return a list of length two 
+#' with target taxon rank names, with additional list of data.frame's of 
+#' intermediate taxonomic groups. Default: \code{FALSE}
+#' @param extant_only (logical) keep extant taxa only? default: \code{FALSE}. 
+#' by default we give back all taxa. set to \code{TRUE} to get only 
+#' extant taxa
+#' @param ... Curl options passed on to \code{\link[crul]{verb-GET}}
+#' @details Provide only names instead of id's
+#' @return A list of data.frame's, where each data.frame has columns:
+#' \itemize{
+#'  \item childtaxa_id: (character) COL identifier
+#'  \item childtaxa_name: (character) taxonomic name
+#'  \item childtaxa_rank: (character) rank name
+#'  \item childtaxa_extinct: (logical) extinct or not
+#' }
 #' @examples \dontrun{
 #' # Some basic examples
 #' col_downstream(name="Apis", downto="species")
@@ -46,10 +55,15 @@
 #' # By id
 #' col_downstream(id='576d098d770a39d09e2bcfa1c0896b26', downto="species",
 #'   checklist=2012)
+#' 
+#' # keep extant taxa only, prunes out extinct taxa
+#' col_downstream(name = "Insecta", downto = "order")
+#' col_downstream(name = "Insecta", downto = "order", extant_only = TRUE)
 #' }
 
 col_downstream <- function(name = NULL, id = NULL, downto, format = NULL,
-  start = NULL, checklist = NULL, verbose = TRUE, intermediate = FALSE, ...) {
+  start = NULL, checklist = NULL, verbose = TRUE, intermediate = FALSE, 
+  extant_only = FALSE, ...) {
 
   downto <- tolower(downto)
   poss_ranks <- unique(do.call(c, sapply(rank_ref$ranks, strsplit, split = ",",
@@ -72,33 +86,42 @@ col_downstream <- function(name = NULL, id = NULL, downto, format = NULL,
       if (is.null(x)) {
         tt <- ldply(toget, function(z) {
           search_col_safe(name = NULL, id = z, checklist = checklist,
-                          format = format, start = start, ...)
+                          format = format, start = start, 
+                          extant_only = extant_only, ...)
         })
       } else {
         tt <- ldply(toget, function(z) {
           search_col_safe(name = z, id = NULL, checklist = checklist,
-                          format = format, start = start, ...)
+                          format = format, start = start, 
+                          extant_only = extant_only, ...)
         })
       }
+      # prune if too low
+      tt <- prune_too_low_col(tt, downto)
 
-      # remove
-      if (NROW(tt[tt$childtaxa_rank == downto, ]) > 0) {
-        out[[iter]] <- tt[tt$childtaxa_rank == downto, ]
-      }
-
-      if (NROW(tt[!tt$childtaxa_rank == downto, ]) > 0) {
-        notout <- tt[!tt$childtaxa_rank %in% torank, ]
+      if (NROW(tt) == 0) {
+        out[[iter]] <- data.frame(stringsAsFactors = FALSE)
+        stop_ <- "nodata"
       } else {
-        notout <- data.frame(rankName = downto)
-      }
+        # remove
+        if (NROW(tt[tt$childtaxa_rank == downto, ]) > 0) {
+          out[[iter]] <- tt[tt$childtaxa_rank == downto, ]
+        }
 
-      if (all(notout$childtaxa_rank == downto)) {
-        stop_ <- "fam"
-      } else {
-        if (intermediate) intermed[[iter]] <- notout
-        x <- NULL
-        toget <- as.character(notout$childtaxa_id)
-        stop_ <- "not"
+        if (NROW(tt[!tt$childtaxa_rank == downto, ]) > 0) {
+          notout <- tt[!tt$childtaxa_rank %in% torank, ]
+        } else {
+          notout <- data.frame(rankName = downto)
+        }
+
+        if (all(notout$childtaxa_rank == downto)) {
+          stop_ <- "fam"
+        } else {
+          if (intermediate) intermed[[iter]] <- notout
+          x <- NULL
+          toget <- as.character(notout$childtaxa_id)
+          stop_ <- "not"
+        }
       }
     } # end while loop
 
