@@ -26,7 +26,7 @@ eubon_hierarchy <- function(id, providers = 'pesi', timeout = 0, ...) {
   args <- tc(list(providers = paste0(providers, collapse = ","),
                   timeout = timeout))
   url <- file.path(eubon_base(), "classification", id, "parent")
-  cli <- crul::HttpClient$new(url, opts = list(...))
+  cli <- crul::HttpClient$new(url, headers = tx_ual, opts = list(...))
   res <- cli$get(query = args)
   eubon_error(res)
   tmp <- jsonlite::fromJSON(res$parse("UTF-8"), TRUE, flatten = TRUE)
