@@ -2,7 +2,7 @@
 #'
 #' @export
 #' @param scientificname (character) scientific names
-#' @param ... Further args passed on to \code{\link[httr]{POST}}
+#' @param ... Further args passed on to \code{\link[crul]{verb-POST}}
 #' @return A \code{data.frame} containing fields extracted from parsed
 #' taxon names. Fields returned are the union of fields extracted from
 #' all species names in \code{scientificname}.
@@ -16,14 +16,13 @@
 #'              'Vanessa atalanta (Linnaeus, 1758)'))
 #' }
 gbif_parse <- function(scientificname, ...) {
-  url <- "http://api.gbif.org/v1/parser/name"
-  tt <- POST(url,
-            config = c(add_headers('Content-Type' =
-                                   'application/json')),
-            body = jsonlite::toJSON(scientificname), ...)
-  stop_for_status(tt)
-  stopifnot(tt$headers$`content-type` == 'application/json')
-  res <- jsonlite::fromJSON(con_utf8(tt), FALSE)
+  cli <- crul::HttpClient$new("https://api.gbif.org", 
+    headers = c(list('Content-Type' = "application/json"), tx_ual),
+    opts = list(...))
+  tt <- cli$post("v1/parser/name", body = jsonlite::toJSON(scientificname))
+  tt$raise_for_status()
+  stopifnot(tt$response_headers$`content-type` == 'application/json')
+  res <- jsonlite::fromJSON(tt$parse("UTF-8"), FALSE)
   res <- lapply(res, function(x) Map(function(z) if (is.null(z)) NA else z, x))
   (tmp <- data.table::setDF(
     data.table::rbindlist(res, fill = TRUE, use.names = TRUE)))
