@@ -89,8 +89,9 @@ get_nbnid <- function(name, ask = TRUE, messages = TRUE, rec_only = FALSE,
   assert(rec_only, "logical")
   assert(rank, "character")
   assert(messages, "logical")
+  assert_rows(rows)
 
-  fun <- function(name, ask, messages, rows) {
+  fun <- function(name, ask, messages, rows, ...) {
     direct <- FALSE
     mssg(messages, "\nRetrieving data for taxon '", name, "'\n")
     df <- nbn_search(q = name, rows = 500, ...)$data
@@ -99,9 +100,7 @@ get_nbnid <- function(name, ask = TRUE, messages = TRUE, rec_only = FALSE,
 
     rank_taken <- NA
     if (NROW(df) == 0) {
-      mssg(
-        messages,
-        "Not found. Consider checking the spelling or alternate classification")
+      mssg(messages, m_not_found_sp_altclass)
       id <- NA_character_
       att <- 'not found'
     } else {
@@ -117,12 +116,21 @@ get_nbnid <- function(name, ask = TRUE, messages = TRUE, rec_only = FALSE,
 
     # not found on NBN
     if (length(id) == 0) {
-      mssg(
-        messages,
-        "Not found. Consider checking the spelling or alternate classification")
+      mssg(messages, m_not_found_sp_altclass)
       id <- NA_character_
       att <- 'not found'
     }
+    # more than one, try for direct match
+    if (length(id) > 1) {
+      matchtmp <- df[tolower(df$scientificName) %in% tolower(name),]
+      if (NROW(matchtmp) == 1) {
+        id <- matchtmp$nbnid
+        rank_taken <- as.character(matchtmp$rank)
+        direct <- TRUE
+        att <- "found"
+      }
+    }
+
     # more than one found -> user input
     if (length(id) > 1) {
       if (ask) {
@@ -152,20 +160,17 @@ get_nbnid <- function(name, ask = TRUE, messages = TRUE, rec_only = FALSE,
         }
       } else{
         if (length(id) != 1) {
-          warning(
-            sprintf("More than one NBN ID found for taxon '%s'; refine query or set ask=TRUE",
-                    name),
-            call. = FALSE
-          )
+          warning(sprintf(m_more_than_one_found, "NBN ID", name),
+            call. = FALSE)
           id <- NA_character_
-          att <- 'NA due to ask=FALSE & > 1 result'
+          att <- m_na_ask_false
         }
       }
     }
     list(id = id, rank = rank_taken, att = att, multiple = mm, direct = direct)
   }
   name <- as.character(name)
-  out <- lapply(name, fun, ask = ask, messages = messages, rows = rows)
+  out <- lapply(name, fun, ask = ask, messages = messages, rows = rows, ...)
   ids <- pluck(out, "id", "")
   atts <- pluck(out, "att", "")
   ids <- structure(ids, class = "nbnid", match = atts,
@@ -237,8 +242,8 @@ make_nbnid <- function(x, check=TRUE) {
 
 check_nbnid <- function(x){
   url <- "https://species-ws.nbnatlas.org/species/"
-  res <- GET(paste0(url, x))
-  if ( res$status_code == 200 ) TRUE else FALSE
+  res <- tax_GET(paste0(url, x))
+  if (res$status_code == 200) TRUE else FALSE
 }
 
 #' @export
