@@ -93,6 +93,7 @@ get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
   assert(accepted, "logical")
   assert(ask, "logical")
   assert(messages, "logical")
+  assert_rows(rows)
 
   fun <- function(x, searchtype, ask, messages, ...) {
     direct <- FALSE
@@ -113,7 +114,7 @@ get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
       att <- "not found"
     } else {
       wmdf <- suppressWarnings(data.frame(wmdf))
-      wmdf <- wmdf[, c("AphiaID","scientificname","authority","status")]
+      wmdf <- wmdf[, c("AphiaID", "scientificname", "authority", "status")]
       names(wmdf)[1] <- "id"
 
       if (accepted) {
@@ -124,42 +125,29 @@ get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
 
       # should return NA if spec not found
       if (nrow(wmdf) == 0) {
-        mssg(
-          messages,
-          "Not found. Consider checking the spelling or alternate classification")
+        mssg(messages, m_not_found_sp_altclass)
         wmid <- NA_character_
-        att <- 'not found'
+        att <- "not found"
       }
 
       # take the one wmid from data.frame
       if (nrow(wmdf) == 1) {
         wmid <- wmdf$id
-        att <- 'found'
+        att <- "found"
       }
 
       # check for direct match
       if (nrow(wmdf) > 1) {
-
         names(wmdf)[grep("scientificname", names(wmdf))] <- "target"
-        direct <- match(tolower(wmdf$target), tolower(x))
-
-        if (length(direct) == 1) {
-          if (!all(is.na(direct))) {
-            wmid <- wmdf$id[!is.na(direct)]
-            direct <- TRUE
-            att <- 'found'
-          } else {
-            direct <- FALSE
-            wmid <- NA_character_
-            att <- 'not found'
-          }
+        matchtmp <- wmdf[tolower(wmdf$target) %in% tolower(x), "id"]
+        if (length(matchtmp) == 1) {
+          wmid <- matchtmp
+          direct <- TRUE
+          att <- "found"
         } else {
-          direct <- FALSE
           wmid <- NA_character_
-          att <- 'NA due to ask=FALSE & no direct match found'
-          warning("> 1 result; no direct match found", call. = FALSE)
+          att <- "not found"
         }
-
       }
 
       # multiple matches
@@ -188,21 +176,18 @@ get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
             take <- as.numeric(take)
             message("Input accepted, took taxon '", as.character(wmdf$target[take]), "'.\n")
             wmid <-  wmdf$id[take]
-            att <- 'found'
+            att <- "found"
           } else {
             wmid <- NA_character_
             mssg(messages, "\nReturned 'NA'!\n\n")
-            att <- 'not found'
+            att <- "not found"
           }
         } else {
           if (length(wmid) != 1) {
-            warning(
-              sprintf("More than one WORMS ID found for taxon '%s'; refine query or set ask=TRUE",
-                      x),
-              call. = FALSE
-            )
+            warning(sprintf(m_more_than_one_found, "Worms ID", x), 
+              call. = FALSE)
             wmid <- NA_character_
-            att <- 'NA due to ask=FALSE & > 1 result'
+            att <- m_na_ask_false
           }
         }
       }
