@@ -1,8 +1,8 @@
-tax_GET <- function(url, path = NULL, query = list(), headers = list(), 
+tax_GET <- function(url, path = NULL, query = list(), headers = list(),
   opts = list(), ...) {
 
-  cli <- crul::HttpClient$new(url, headers = headers, 
-    opts = c(opts, list(...)))
+  cli <- crul::HttpClient$new(url,
+    headers = c(headers, tx_ual), opts = c(opts, list(...)))
   out <- cli$get(path = path, query = query)
   out$raise_for_status()
   return(out)
@@ -11,8 +11,8 @@ tax_GET <- function(url, path = NULL, query = list(), headers = list(),
 tax_POST <- function(url, path = NULL, query = list(), body = list(),
   headers = list(), opts = list(), ...) {
 
-  cli <- crul::HttpClient$new(url, headers = headers, 
-    opts = c(opts, list(...)))
+  cli <- crul::HttpClient$new(url,
+    headers = c(headers, tx_ual), opts = c(opts, list(...)))
   out <- cli$post(path = path, query = query, body = body)
   out$raise_for_status()
   return(out)
