@@ -44,7 +44,7 @@ itis_downstream <- function(tsns, downto, intermediate = FALSE, ...) {
 	stop_ <- "not"
 	notout <- data.frame(rankname = "")
 	out <- list()
-  if (intermediate) intermed <- list()
+	if (intermediate) intermed <- list()
 	iter <- 0
 	while (stop_ == "not") {
 		iter <- iter + 1
@@ -94,10 +94,3 @@ itis_downstream <- function(tsns, downto, intermediate = FALSE, ...) {
     stats::setNames(tmp, tolower(names(tmp)))
   }
 }
-
-which_rank <- function(x) {
-  which(sapply(rank_ref$ranks, function(z) {
-    any(unlist(strsplit(z, split = ",")) == x)
-  }, USE.NAMES = FALSE)
-  )
-}
