@@ -2,11 +2,13 @@
 #'
 #' @export
 #' @param scinames character; One or more scientific names or partial names.
-#' @param db character; Data source, one of \emph{"eol"} (default),
-#' \emph{"itis"} \emph{"ncbi"}, \emph{"worms"}, or \emph{"iucn"}. Note that
+#' @param db character; Data source, one of \emph{"ncbi"} (default),
+#' \emph{"itis"} \emph{"eol"}, \emph{"worms"}, or \emph{"iucn"}. Note that
 #' each taxonomic data source has their own identifiers,  so that if you
 #' provide the wrong \code{db} value for the identifier you could get a
-#' result, but it will likely be wrong (not what you were expecting).
+#' result, but it will likely be wrong (not what you were expecting). 
+#' If using ncbi, eol or iucn we recommend getting an API key; 
+#' see \code{\link{taxize-authentication}}
 #' @param simplify (logical) If TRUE, simplify output to a vector of names.
 #' If FALSE, return variable formats from different sources, usually a
 #' data.frame. Only applies to eol and itis. Specify \code{FALSE} to obtain
@@ -26,6 +28,7 @@
 #' @author Scott Chamberlain (myrmecocystus@@gmail.com)
 #'
 #' @examples \dontrun{
+#' sci2comm(scinames='Helianthus annuus')
 #' sci2comm(scinames='Helianthus annuus', db='eol')
 #' sci2comm(scinames='Helianthus annuus', db='itis')
 #' sci2comm(scinames=c('Helianthus annuus', 'Poa annua'))
@@ -55,7 +58,7 @@ sci2comm <- function(...){
 #' @method sci2comm default
 #' @export
 #' @rdname sci2comm
-sci2comm.default <- function(scinames, db='eol', simplify=TRUE, ...) {
+sci2comm.default <- function(scinames, db='ncbi', simplify=TRUE, ...) {
   temp <- lapply(scinames, getsci, db = db, simplify = simplify, ...)
   stats::setNames(temp, scinames)
 }
@@ -112,7 +115,7 @@ eol2comm <- function(x, simplify, ...){
         eol_pages(taxonconceptID = x, common_names = TRUE, ...),
         error = function(e) e
       )
-      if (inherits(tmp, "error")) NULL else tmp$vernac
+      if (inherits(tmp, "error")) NULL else tmp$vernacular
     })
   )
   tt <- ldply(dfs[sapply(dfs, class) == "data.frame"])
@@ -173,7 +176,8 @@ itis_foo <- function(x, simplify=TRUE, ...){
 ncbi_foo <- function(x, ...){
   key <- getkey(NULL, "ENTREZ_KEY")
   query <- tc(list(db = "taxonomy", ID = x, api_key = key))
-  cli <- crul::HttpClient$new(url = ncbi_base(), opts = list(...))
+  cli <- crul::HttpClient$new(url = ncbi_base(), headers = tx_ual,
+    opts = list(...))
   res <- cli$get("entrez/eutils/efetch.fcgi", query = query)
   res$raise_for_status()
   tt <- res$parse("UTF-8")
