@@ -1,36 +1,28 @@
-# tests for gbif_downstream fxn in taxize
 context("gbif_downstream")
 
 test_that("gbif_downstream works", {
-  skip_on_cran()
+  vcr::use_cassette("gbif_downstream", {
+    aa <- gbif_downstream(key = 198, downto = "Genus")
+    bb <- gbif_downstream(key = 1227, "Family")
+  })
 
-	aa <- gbif_downstream(key = 198, downto = "Genus")
-
-	expect_is(aa, "data.frame")
-	expect_is(aa$name, "character")
-	expect_is(aa$rank, "character")
-	expect_is(aa$key, "integer")
-
-	expect_equal(unique(aa$rank), "genus")
-})
-
-test_that("gbif_downstream works, more egs", {
-  skip_on_cran()
-
-  bb <- gbif_downstream(key = 1227, "Family")
+  expect_is(aa, "data.frame")
+  expect_is(aa$name, "character")
+  expect_is(aa$rank, "character")
+  expect_is(aa$key, "integer")
+  expect_equal(unique(aa$rank), "genus")
 
   expect_is(bb, "data.frame")
   expect_is(bb$name, "character")
   expect_is(bb$rank, "character")
   expect_is(bb$key, "integer")
-
   expect_equal(unique(bb$rank), "family")
 })
 
 test_that("gbif_downstream intermediate param works", {
-  skip_on_cran()
-
-  cc <- gbif_downstream(key = 198, downto = "genus", intermediate = TRUE)
+  vcr::use_cassette("gbif_downstream_intermediate", {
+    cc <- gbif_downstream(key = 198, downto = "genus", intermediate = TRUE)
+  })
 
   expect_is(cc, "list")
   expect_is(cc$target, "data.frame")
@@ -44,10 +36,10 @@ test_that("gbif_downstream intermediate param works", {
 })
 
 test_that("gbif_downstream - limit and start params", {
-  skip_on_cran()
-
-  aa <- gbif_downstream(2978223, "species", limit = 3)
-  bb <- gbif_downstream(2978223, "species", limit = 3, start = 3)
+  vcr::use_cassette("gbif_downstream_pagination", {
+    aa <- gbif_downstream(2978223, "species", limit = 3)
+    bb <- gbif_downstream(2978223, "species", limit = 3, start = 3)
+  })
 
   expect_is(aa, "data.frame")
   expect_is(bb, "data.frame")
