@@ -1,10 +1,9 @@
-# tests for itis_kingdomnames fxn in taxize
 context("itis_kingdomnames")
 
 test_that("itis_kingdomnames - all", {
-  skip_on_cran()
-
-  aa <- itis_kingdomnames()
+  vcr::use_cassette("itis_kingdomnames", {
+    aa <- itis_kingdomnames()
+  })
 
   expect_is(aa, "tbl_df")
   expect_named(aa, c('kingdomid', 'kingdomname', 'tsn'))
@@ -13,10 +12,10 @@ test_that("itis_kingdomnames - all", {
 })
 
 test_that("itis_kingdomnames - with TSN's", {
-  skip_on_cran()
-
-  one <- itis_kingdomnames(202385)
-  two <- itis_kingdomnames(tsn = c(202385, 183833, 180543))
+  vcr::use_cassette("itis_kingdomnames_with_tsns", {
+    one <- itis_kingdomnames(202385)
+    two <- itis_kingdomnames(tsn = c(202385, 183833, 180543))
+  })
 
   expect_match(one, "Animalia")
   expect_match(two[[1]], "Animalia")
@@ -26,8 +25,8 @@ test_that("itis_kingdomnames - with TSN's", {
 })
 
 test_that("itis_kingdomnames returns error when not found", {
-  skip_on_cran()
-
-  expect_error(length(itis_kingdomnames("stuff")[[1]]),
-    "Bad Request \\(HTTP 400\\)")
+  vcr::use_cassette("itis_kingdomnames_fail_well", {
+    expect_error(length(itis_kingdomnames("stuff")[[1]]),
+      "Bad Request \\(HTTP 400\\)")
+  })
 })
