@@ -1,13 +1,14 @@
-# tests for sci2comm fxn in taxize
 context("sci2comm")
 
-
 test_that("sci2comm returns the correct value", {
-  skip_on_cran()
-
-  tt <- sci2comm(scinames = 'Helianthus annuus', db = 'ncbi', verbose = FALSE)
-  uu <- sci2comm(scinames = 'Helianthus annuus', db = 'itis', verbose = FALSE)
-  zz <- sci2comm(scinames = 'Pomatomus saltatrix', db = 'worms', verbose = FALSE)
+  skip_on_cran() # uses secrets
+  vcr::use_cassette("sci2comm", {
+    tt <- sci2comm(scinames = 'Helianthus annuus', db = 'ncbi', verbose = FALSE)
+    uu <- sw(sci2comm(scinames = 'Helianthus annuus', db = 'itis', rows = 1,
+                      verbose = FALSE))
+    zz <- sci2comm(scinames = 'Pomatomus saltatrix', db = 'worms',
+                   verbose = FALSE)
+  })
 
   expect_that(names(tt), equals('Helianthus annuus'))
   expect_that(names(uu), equals('Helianthus annuus'))
